# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['yalm',
 'yalm.resources',
 'yalm.resources.regex',
 'yalm.resources.template',
 'yalm.resources.tests',
 'yalm.resources.tests.classfier',
 'yalm.resources.tests.classfier.positive',
 'yalm.resources.tests.classfier.positive.0BSD',
 'yalm.resources.tests.classfier.positive.AAL',
 'yalm.resources.tests.classfier.positive.ADSL',
 'yalm.resources.tests.classfier.positive.AFL_1_1',
 'yalm.resources.tests.classfier.positive.AFL_1_2',
 'yalm.resources.tests.classfier.positive.AFL_2_0',
 'yalm.resources.tests.classfier.positive.AFL_2_1',
 'yalm.resources.tests.classfier.positive.AFL_3_0',
 'yalm.resources.tests.classfier.positive.AGPL_1_0',
 'yalm.resources.tests.classfier.positive.AGPL_1_0_only',
 'yalm.resources.tests.classfier.positive.AGPL_1_0_or_later',
 'yalm.resources.tests.classfier.positive.AGPL_3_0',
 'yalm.resources.tests.classfier.positive.AGPL_3_0_only',
 'yalm.resources.tests.classfier.positive.AGPL_3_0_or_later',
 'yalm.resources.tests.classfier.positive.AMDPLPA',
 'yalm.resources.tests.classfier.positive.AML',
 'yalm.resources.tests.classfier.positive.AMPAS',
 'yalm.resources.tests.classfier.positive.ANTLR_PD',
 'yalm.resources.tests.classfier.positive.ANTLR_PD_fallback',
 'yalm.resources.tests.classfier.positive.APAFML',
 'yalm.resources.tests.classfier.positive.APL_1_0',
 'yalm.resources.tests.classfier.positive.APSL_1_0',
 'yalm.resources.tests.classfier.positive.APSL_1_1',
 'yalm.resources.tests.classfier.positive.APSL_1_2',
 'yalm.resources.tests.classfier.positive.APSL_2_0',
 'yalm.resources.tests.classfier.positive.Abstyles',
 'yalm.resources.tests.classfier.positive.Adobe_2006',
 'yalm.resources.tests.classfier.positive.Adobe_Glyph',
 'yalm.resources.tests.classfier.positive.Afmparse',
 'yalm.resources.tests.classfier.positive.Aladdin',
 'yalm.resources.tests.classfier.positive.Apache_1_0',
 'yalm.resources.tests.classfier.positive.Apache_1_1',
 'yalm.resources.tests.classfier.positive.Apache_2_0',
 'yalm.resources.tests.classfier.positive.Artistic_1_0',
 'yalm.resources.tests.classfier.positive.Artistic_1_0_Perl',
 'yalm.resources.tests.classfier.positive.Artistic_1_0_cl8',
 'yalm.resources.tests.classfier.positive.Artistic_2_0',
 'yalm.resources.tests.classfier.positive.BSD_1_Clause',
 'yalm.resources.tests.classfier.positive.BSD_2_Clause',
 'yalm.resources.tests.classfier.positive.BSD_2_Clause_FreeBSD',
 'yalm.resources.tests.classfier.positive.BSD_2_Clause_NetBSD',
 'yalm.resources.tests.classfier.positive.BSD_2_Clause_Patent',
 'yalm.resources.tests.classfier.positive.BSD_2_Clause_Views',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_Attribution',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_Clear',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_LBNL',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_Modification',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_No_Military_License',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_No_Nuclear_License',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_No_Nuclear_License_2014',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_No_Nuclear_Warranty',
 'yalm.resources.tests.classfier.positive.BSD_3_Clause_Open_MPI',
 'yalm.resources.tests.classfier.positive.BSD_4_Clause',
 'yalm.resources.tests.classfier.positive.BSD_4_Clause_Shortened',
 'yalm.resources.tests.classfier.positive.BSD_4_Clause_UC',
 'yalm.resources.tests.classfier.positive.BSD_Protection',
 'yalm.resources.tests.classfier.positive.BSD_Source_Code',
 'yalm.resources.tests.classfier.positive.BSL_1_0',
 'yalm.resources.tests.classfier.positive.BUSL_1_1',
 'yalm.resources.tests.classfier.positive.Bahyph',
 'yalm.resources.tests.classfier.positive.Barr',
 'yalm.resources.tests.classfier.positive.Beerware',
 'yalm.resources.tests.classfier.positive.BitTorrent_1_0',
 'yalm.resources.tests.classfier.positive.BitTorrent_1_1',
 'yalm.resources.tests.classfier.positive.BlueOak_1_0_0',
 'yalm.resources.tests.classfier.positive.Borceux',
 'yalm.resources.tests.classfier.positive.CAL_1_0',
 'yalm.resources.tests.classfier.positive.CAL_1_0_Combined_Work_Exception',
 'yalm.resources.tests.classfier.positive.CATOSL_1_1',
 'yalm.resources.tests.classfier.positive.CC0_1_0',
 'yalm.resources.tests.classfier.positive.CC_BY_1_0',
 'yalm.resources.tests.classfier.positive.CC_BY_2_0',
 'yalm.resources.tests.classfier.positive.CC_BY_2_5',
 'yalm.resources.tests.classfier.positive.CC_BY_3_0',
 'yalm.resources.tests.classfier.positive.CC_BY_3_0_AT',
 'yalm.resources.tests.classfier.positive.CC_BY_3_0_US',
 'yalm.resources.tests.classfier.positive.CC_BY_4_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_1_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_2_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_2_5',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_3_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_4_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_ND_1_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_ND_2_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_ND_2_5',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_ND_3_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_ND_3_0_IGO',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_ND_4_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_SA_1_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_SA_2_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_SA_2_5',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_SA_3_0',
 'yalm.resources.tests.classfier.positive.CC_BY_NC_SA_4_0',
 'yalm.resources.tests.classfier.positive.CC_BY_ND_1_0',
 'yalm.resources.tests.classfier.positive.CC_BY_ND_2_0',
 'yalm.resources.tests.classfier.positive.CC_BY_ND_2_5',
 'yalm.resources.tests.classfier.positive.CC_BY_ND_3_0',
 'yalm.resources.tests.classfier.positive.CC_BY_ND_4_0',
 'yalm.resources.tests.classfier.positive.CC_BY_SA_1_0',
 'yalm.resources.tests.classfier.positive.CC_BY_SA_2_0',
 'yalm.resources.tests.classfier.positive.CC_BY_SA_2_0_UK',
 'yalm.resources.tests.classfier.positive.CC_BY_SA_2_1_JP',
 'yalm.resources.tests.classfier.positive.CC_BY_SA_2_5',
 'yalm.resources.tests.classfier.positive.CC_BY_SA_3_0',
 'yalm.resources.tests.classfier.positive.CC_BY_SA_3_0_AT',
 'yalm.resources.tests.classfier.positive.CC_BY_SA_4_0',
 'yalm.resources.tests.classfier.positive.CC_PDDC',
 'yalm.resources.tests.classfier.positive.CDDL_1_0',
 'yalm.resources.tests.classfier.positive.CDDL_1_1',
 'yalm.resources.tests.classfier.positive.CDLA_Permissive_1_0',
 'yalm.resources.tests.classfier.positive.CDLA_Sharing_1_0',
 'yalm.resources.tests.classfier.positive.CDL_1_0',
 'yalm.resources.tests.classfier.positive.CECILL_1_0',
 'yalm.resources.tests.classfier.positive.CECILL_1_1',
 'yalm.resources.tests.classfier.positive.CECILL_2_0',
 'yalm.resources.tests.classfier.positive.CECILL_2_1',
 'yalm.resources.tests.classfier.positive.CECILL_B',
 'yalm.resources.tests.classfier.positive.CECILL_C',
 'yalm.resources.tests.classfier.positive.CERN_OHL_1_1',
 'yalm.resources.tests.classfier.positive.CERN_OHL_1_2',
 'yalm.resources.tests.classfier.positive.CERN_OHL_P_2_0',
 'yalm.resources.tests.classfier.positive.CERN_OHL_S_2_0',
 'yalm.resources.tests.classfier.positive.CERN_OHL_W_2_0',
 'yalm.resources.tests.classfier.positive.CNRI_Jython',
 'yalm.resources.tests.classfier.positive.CNRI_Python',
 'yalm.resources.tests.classfier.positive.CNRI_Python_GPL_Compatible',
 'yalm.resources.tests.classfier.positive.CPAL_1_0',
 'yalm.resources.tests.classfier.positive.CPL_1_0',
 'yalm.resources.tests.classfier.positive.CPOL_1_02',
 'yalm.resources.tests.classfier.positive.CUA_OPL_1_0',
 'yalm.resources.tests.classfier.positive.C_UDA_1_0',
 'yalm.resources.tests.classfier.positive.Caldera',
 'yalm.resources.tests.classfier.positive.ClArtistic',
 'yalm.resources.tests.classfier.positive.Condor_1_1',
 'yalm.resources.tests.classfier.positive.Crossword',
 'yalm.resources.tests.classfier.positive.CrystalStacker',
 'yalm.resources.tests.classfier.positive.Cube',
 'yalm.resources.tests.classfier.positive.DOC',
 'yalm.resources.tests.classfier.positive.DRL_1_0',
 'yalm.resources.tests.classfier.positive.DSDP',
 'yalm.resources.tests.classfier.positive.D_FSL_1_0',
 'yalm.resources.tests.classfier.positive.Dotseqn',
 'yalm.resources.tests.classfier.positive.ECL_1_0',
 'yalm.resources.tests.classfier.positive.ECL_2_0',
 'yalm.resources.tests.classfier.positive.EFL_1_0',
 'yalm.resources.tests.classfier.positive.EFL_2_0',
 'yalm.resources.tests.classfier.positive.EPICS',
 'yalm.resources.tests.classfier.positive.EPL_1_0',
 'yalm.resources.tests.classfier.positive.EPL_2_0',
 'yalm.resources.tests.classfier.positive.EUDatagrid',
 'yalm.resources.tests.classfier.positive.EUPL_1_0',
 'yalm.resources.tests.classfier.positive.EUPL_1_1',
 'yalm.resources.tests.classfier.positive.EUPL_1_2',
 'yalm.resources.tests.classfier.positive.Entessa',
 'yalm.resources.tests.classfier.positive.ErlPL_1_1',
 'yalm.resources.tests.classfier.positive.Eurosym',
 'yalm.resources.tests.classfier.positive.FSFAP',
 'yalm.resources.tests.classfier.positive.FSFUL',
 'yalm.resources.tests.classfier.positive.FSFULLR',
 'yalm.resources.tests.classfier.positive.FTL',
 'yalm.resources.tests.classfier.positive.Fair',
 'yalm.resources.tests.classfier.positive.Frameworx_1_0',
 'yalm.resources.tests.classfier.positive.FreeBSD_DOC',
 'yalm.resources.tests.classfier.positive.FreeImage',
 'yalm.resources.tests.classfier.positive.GD',
 'yalm.resources.tests.classfier.positive.GFDL_1_1',
 'yalm.resources.tests.classfier.positive.GFDL_1_1_invariants_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_1_invariants_or_later',
 'yalm.resources.tests.classfier.positive.GFDL_1_1_no_invariants_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_1_no_invariants_or_later',
 'yalm.resources.tests.classfier.positive.GFDL_1_1_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_1_or_later',
 'yalm.resources.tests.classfier.positive.GFDL_1_2',
 'yalm.resources.tests.classfier.positive.GFDL_1_2_invariants_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_2_invariants_or_later',
 'yalm.resources.tests.classfier.positive.GFDL_1_2_no_invariants_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_2_no_invariants_or_later',
 'yalm.resources.tests.classfier.positive.GFDL_1_2_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_2_or_later',
 'yalm.resources.tests.classfier.positive.GFDL_1_3',
 'yalm.resources.tests.classfier.positive.GFDL_1_3_invariants_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_3_invariants_or_later',
 'yalm.resources.tests.classfier.positive.GFDL_1_3_no_invariants_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_3_no_invariants_or_later',
 'yalm.resources.tests.classfier.positive.GFDL_1_3_only',
 'yalm.resources.tests.classfier.positive.GFDL_1_3_or_later',
 'yalm.resources.tests.classfier.positive.GL2PS',
 'yalm.resources.tests.classfier.positive.GLWTPL',
 'yalm.resources.tests.classfier.positive.GPL_1_0',
 'yalm.resources.tests.classfier.positive.GPL_1_0_',
 'yalm.resources.tests.classfier.positive.GPL_1_0_only',
 'yalm.resources.tests.classfier.positive.GPL_1_0_or_later',
 'yalm.resources.tests.classfier.positive.GPL_2_0',
 'yalm.resources.tests.classfier.positive.GPL_2_0_',
 'yalm.resources.tests.classfier.positive.GPL_2_0_only',
 'yalm.resources.tests.classfier.positive.GPL_2_0_or_later',
 'yalm.resources.tests.classfier.positive.GPL_2_0_with_GCC_exception',
 'yalm.resources.tests.classfier.positive.GPL_2_0_with_autoconf_exception',
 'yalm.resources.tests.classfier.positive.GPL_2_0_with_bison_exception',
 'yalm.resources.tests.classfier.positive.GPL_2_0_with_classpath_exception',
 'yalm.resources.tests.classfier.positive.GPL_2_0_with_font_exception',
 'yalm.resources.tests.classfier.positive.GPL_3_0',
 'yalm.resources.tests.classfier.positive.GPL_3_0_',
 'yalm.resources.tests.classfier.positive.GPL_3_0_only',
 'yalm.resources.tests.classfier.positive.GPL_3_0_or_later',
 'yalm.resources.tests.classfier.positive.GPL_3_0_with_GCC_exception',
 'yalm.resources.tests.classfier.positive.GPL_3_0_with_autoconf_exception',
 'yalm.resources.tests.classfier.positive.Giftware',
 'yalm.resources.tests.classfier.positive.Glide',
 'yalm.resources.tests.classfier.positive.Glulxe',
 'yalm.resources.tests.classfier.positive.HPND',
 'yalm.resources.tests.classfier.positive.HPND_sell_variant',
 'yalm.resources.tests.classfier.positive.HTMLTIDY',
 'yalm.resources.tests.classfier.positive.HaskellReport',
 'yalm.resources.tests.classfier.positive.Hippocratic_2_1',
 'yalm.resources.tests.classfier.positive.IBM_pibs',
 'yalm.resources.tests.classfier.positive.ICU',
 'yalm.resources.tests.classfier.positive.IJG',
 'yalm.resources.tests.classfier.positive.IPA',
 'yalm.resources.tests.classfier.positive.IPL_1_0',
 'yalm.resources.tests.classfier.positive.ISC',
 'yalm.resources.tests.classfier.positive.ImageMagick',
 'yalm.resources.tests.classfier.positive.Imlib2',
 'yalm.resources.tests.classfier.positive.Info_ZIP',
 'yalm.resources.tests.classfier.positive.Intel',
 'yalm.resources.tests.classfier.positive.Intel_ACPI',
 'yalm.resources.tests.classfier.positive.Interbase_1_0',
 'yalm.resources.tests.classfier.positive.JPNIC',
 'yalm.resources.tests.classfier.positive.JSON',
 'yalm.resources.tests.classfier.positive.JasPer_2_0',
 'yalm.resources.tests.classfier.positive.LAL_1_2',
 'yalm.resources.tests.classfier.positive.LAL_1_3',
 'yalm.resources.tests.classfier.positive.LGPLLR',
 'yalm.resources.tests.classfier.positive.LGPL_2_0',
 'yalm.resources.tests.classfier.positive.LGPL_2_0_',
 'yalm.resources.tests.classfier.positive.LGPL_2_0_only',
 'yalm.resources.tests.classfier.positive.LGPL_2_0_or_later',
 'yalm.resources.tests.classfier.positive.LGPL_2_1',
 'yalm.resources.tests.classfier.positive.LGPL_2_1_',
 'yalm.resources.tests.classfier.positive.LGPL_2_1_only',
 'yalm.resources.tests.classfier.positive.LGPL_2_1_or_later',
 'yalm.resources.tests.classfier.positive.LGPL_3_0',
 'yalm.resources.tests.classfier.positive.LGPL_3_0_',
 'yalm.resources.tests.classfier.positive.LGPL_3_0_only',
 'yalm.resources.tests.classfier.positive.LGPL_3_0_or_later',
 'yalm.resources.tests.classfier.positive.LPL_1_0',
 'yalm.resources.tests.classfier.positive.LPL_1_02',
 'yalm.resources.tests.classfier.positive.LPPL_1_0',
 'yalm.resources.tests.classfier.positive.LPPL_1_1',
 'yalm.resources.tests.classfier.positive.LPPL_1_2',
 'yalm.resources.tests.classfier.positive.LPPL_1_3a',
 'yalm.resources.tests.classfier.positive.LPPL_1_3c',
 'yalm.resources.tests.classfier.positive.Latex2e',
 'yalm.resources.tests.classfier.positive.Leptonica',
 'yalm.resources.tests.classfier.positive.LiLiQ_P_1_1',
 'yalm.resources.tests.classfier.positive.LiLiQ_R_1_1',
 'yalm.resources.tests.classfier.positive.LiLiQ_Rplus_1_1',
 'yalm.resources.tests.classfier.positive.Libpng',
 'yalm.resources.tests.classfier.positive.Linux_OpenIB',
 'yalm.resources.tests.classfier.positive.MIT',
 'yalm.resources.tests.classfier.positive.MITNFA',
 'yalm.resources.tests.classfier.positive.MIT_0',
 'yalm.resources.tests.classfier.positive.MIT_CMU',
 'yalm.resources.tests.classfier.positive.MIT_Modern_Variant',
 'yalm.resources.tests.classfier.positive.MIT_advertising',
 'yalm.resources.tests.classfier.positive.MIT_enna',
 'yalm.resources.tests.classfier.positive.MIT_feh',
 'yalm.resources.tests.classfier.positive.MIT_open_group',
 'yalm.resources.tests.classfier.positive.MPL_1_0',
 'yalm.resources.tests.classfier.positive.MPL_1_1',
 'yalm.resources.tests.classfier.positive.MPL_2_0',
 'yalm.resources.tests.classfier.positive.MPL_2_0_no_copyleft_exception',
 'yalm.resources.tests.classfier.positive.MS_PL',
 'yalm.resources.tests.classfier.positive.MS_RL',
 'yalm.resources.tests.classfier.positive.MTLL',
 'yalm.resources.tests.classfier.positive.MakeIndex',
 'yalm.resources.tests.classfier.positive.MirOS',
 'yalm.resources.tests.classfier.positive.Motosoto',
 'yalm.resources.tests.classfier.positive.MulanPSL_1_0',
 'yalm.resources.tests.classfier.positive.MulanPSL_2_0',
 'yalm.resources.tests.classfier.positive.Multics',
 'yalm.resources.tests.classfier.positive.Mup',
 'yalm.resources.tests.classfier.positive.NAIST_2003',
 'yalm.resources.tests.classfier.positive.NASA_1_3',
 'yalm.resources.tests.classfier.positive.NBPL_1_0',
 'yalm.resources.tests.classfier.positive.NCGL_UK_2_0',
 'yalm.resources.tests.classfier.positive.NCSA',
 'yalm.resources.tests.classfier.positive.NGPL',
 'yalm.resources.tests.classfier.positive.NIST_PD',
 'yalm.resources.tests.classfier.positive.NIST_PD_fallback',
 'yalm.resources.tests.classfier.positive.NLOD_1_0',
 'yalm.resources.tests.classfier.positive.NLPL',
 'yalm.resources.tests.classfier.positive.NOSL',
 'yalm.resources.tests.classfier.positive.NPL_1_0',
 'yalm.resources.tests.classfier.positive.NPL_1_1',
 'yalm.resources.tests.classfier.positive.NPOSL_3_0',
 'yalm.resources.tests.classfier.positive.NRL',
 'yalm.resources.tests.classfier.positive.NTP',
 'yalm.resources.tests.classfier.positive.NTP_0',
 'yalm.resources.tests.classfier.positive.Naumen',
 'yalm.resources.tests.classfier.positive.NetCDF',
 'yalm.resources.tests.classfier.positive.Net_SNMP',
 'yalm.resources.tests.classfier.positive.Newsletr',
 'yalm.resources.tests.classfier.positive.Nokia',
 'yalm.resources.tests.classfier.positive.Noweb',
 'yalm.resources.tests.classfier.positive.Nunit',
 'yalm.resources.tests.classfier.positive.OCCT_PL',
 'yalm.resources.tests.classfier.positive.OCLC_2_0',
 'yalm.resources.tests.classfier.positive.ODC_By_1_0',
 'yalm.resources.tests.classfier.positive.ODbL_1_0',
 'yalm.resources.tests.classfier.positive.OFL_1_0',
 'yalm.resources.tests.classfier.positive.OFL_1_0_RFN',
 'yalm.resources.tests.classfier.positive.OFL_1_0_no_RFN',
 'yalm.resources.tests.classfier.positive.OFL_1_1',
 'yalm.resources.tests.classfier.positive.OFL_1_1_RFN',
 'yalm.resources.tests.classfier.positive.OFL_1_1_no_RFN',
 'yalm.resources.tests.classfier.positive.OGC_1_0',
 'yalm.resources.tests.classfier.positive.OGDL_Taiwan_1_0',
 'yalm.resources.tests.classfier.positive.OGL_Canada_2_0',
 'yalm.resources.tests.classfier.positive.OGL_UK_1_0',
 'yalm.resources.tests.classfier.positive.OGL_UK_2_0',
 'yalm.resources.tests.classfier.positive.OGL_UK_3_0',
 'yalm.resources.tests.classfier.positive.OGTSL',
 'yalm.resources.tests.classfier.positive.OLDAP_1_1',
 'yalm.resources.tests.classfier.positive.OLDAP_1_2',
 'yalm.resources.tests.classfier.positive.OLDAP_1_3',
 'yalm.resources.tests.classfier.positive.OLDAP_1_4',
 'yalm.resources.tests.classfier.positive.OLDAP_2_0',
 'yalm.resources.tests.classfier.positive.OLDAP_2_0_1',
 'yalm.resources.tests.classfier.positive.OLDAP_2_1',
 'yalm.resources.tests.classfier.positive.OLDAP_2_2',
 'yalm.resources.tests.classfier.positive.OLDAP_2_2_1',
 'yalm.resources.tests.classfier.positive.OLDAP_2_2_2',
 'yalm.resources.tests.classfier.positive.OLDAP_2_3',
 'yalm.resources.tests.classfier.positive.OLDAP_2_4',
 'yalm.resources.tests.classfier.positive.OLDAP_2_5',
 'yalm.resources.tests.classfier.positive.OLDAP_2_6',
 'yalm.resources.tests.classfier.positive.OLDAP_2_7',
 'yalm.resources.tests.classfier.positive.OLDAP_2_8',
 'yalm.resources.tests.classfier.positive.OML',
 'yalm.resources.tests.classfier.positive.OPL_1_0',
 'yalm.resources.tests.classfier.positive.OSET_PL_2_1',
 'yalm.resources.tests.classfier.positive.OSL_1_0',
 'yalm.resources.tests.classfier.positive.OSL_1_1',
 'yalm.resources.tests.classfier.positive.OSL_2_0',
 'yalm.resources.tests.classfier.positive.OSL_2_1',
 'yalm.resources.tests.classfier.positive.OSL_3_0',
 'yalm.resources.tests.classfier.positive.O_UDA_1_0',
 'yalm.resources.tests.classfier.positive.OpenSSL',
 'yalm.resources.tests.classfier.positive.PDDL_1_0',
 'yalm.resources.tests.classfier.positive.PHP_3_0',
 'yalm.resources.tests.classfier.positive.PHP_3_01',
 'yalm.resources.tests.classfier.positive.PSF_2_0',
 'yalm.resources.tests.classfier.positive.Parity_6_0_0',
 'yalm.resources.tests.classfier.positive.Parity_7_0_0',
 'yalm.resources.tests.classfier.positive.Plexus',
 'yalm.resources.tests.classfier.positive.PolyForm_Noncommercial_1_0_0',
 'yalm.resources.tests.classfier.positive.PolyForm_Small_Business_1_0_0',
 'yalm.resources.tests.classfier.positive.PostgreSQL',
 'yalm.resources.tests.classfier.positive.Python_2_0',
 'yalm.resources.tests.classfier.positive.QPL_1_0',
 'yalm.resources.tests.classfier.positive.Qhull',
 'yalm.resources.tests.classfier.positive.RHeCos_1_1',
 'yalm.resources.tests.classfier.positive.RPL_1_1',
 'yalm.resources.tests.classfier.positive.RPL_1_5',
 'yalm.resources.tests.classfier.positive.RPSL_1_0',
 'yalm.resources.tests.classfier.positive.RSA_MD',
 'yalm.resources.tests.classfier.positive.RSCPL',
 'yalm.resources.tests.classfier.positive.Rdisc',
 'yalm.resources.tests.classfier.positive.Ruby',
 'yalm.resources.tests.classfier.positive.SAX_PD',
 'yalm.resources.tests.classfier.positive.SCEA',
 'yalm.resources.tests.classfier.positive.SGI_B_1_0',
 'yalm.resources.tests.classfier.positive.SGI_B_1_1',
 'yalm.resources.tests.classfier.positive.SGI_B_2_0',
 'yalm.resources.tests.classfier.positive.SHL_0_5',
 'yalm.resources.tests.classfier.positive.SHL_0_51',
 'yalm.resources.tests.classfier.positive.SISSL',
 'yalm.resources.tests.classfier.positive.SISSL_1_2',
 'yalm.resources.tests.classfier.positive.SMLNJ',
 'yalm.resources.tests.classfier.positive.SMPPL',
 'yalm.resources.tests.classfier.positive.SNIA',
 'yalm.resources.tests.classfier.positive.SPL_1_0',
 'yalm.resources.tests.classfier.positive.SSH_OpenSSH',
 'yalm.resources.tests.classfier.positive.SSH_short',
 'yalm.resources.tests.classfier.positive.SSPL_1_0',
 'yalm.resources.tests.classfier.positive.SWL',
 'yalm.resources.tests.classfier.positive.Saxpath',
 'yalm.resources.tests.classfier.positive.Sendmail',
 'yalm.resources.tests.classfier.positive.Sendmail_8_23',
 'yalm.resources.tests.classfier.positive.SimPL_2_0',
 'yalm.resources.tests.classfier.positive.Sleepycat',
 'yalm.resources.tests.classfier.positive.Spencer_86',
 'yalm.resources.tests.classfier.positive.Spencer_94',
 'yalm.resources.tests.classfier.positive.Spencer_99',
 'yalm.resources.tests.classfier.positive.StandardML_NJ',
 'yalm.resources.tests.classfier.positive.SugarCRM_1_1_3',
 'yalm.resources.tests.classfier.positive.TAPR_OHL_1_0',
 'yalm.resources.tests.classfier.positive.TCL',
 'yalm.resources.tests.classfier.positive.TCP_wrappers',
 'yalm.resources.tests.classfier.positive.TMate',
 'yalm.resources.tests.classfier.positive.TORQUE_1_1',
 'yalm.resources.tests.classfier.positive.TOSL',
 'yalm.resources.tests.classfier.positive.TU_Berlin_1_0',
 'yalm.resources.tests.classfier.positive.TU_Berlin_2_0',
 'yalm.resources.tests.classfier.positive.UCL_1_0',
 'yalm.resources.tests.classfier.positive.UPL_1_0',
 'yalm.resources.tests.classfier.positive.Unicode_DFS_2015',
 'yalm.resources.tests.classfier.positive.Unicode_DFS_2016',
 'yalm.resources.tests.classfier.positive.Unicode_TOU',
 'yalm.resources.tests.classfier.positive.Unlicense',
 'yalm.resources.tests.classfier.positive.VOSTROM',
 'yalm.resources.tests.classfier.positive.VSL_1_0',
 'yalm.resources.tests.classfier.positive.Vim',
 'yalm.resources.tests.classfier.positive.W3C',
 'yalm.resources.tests.classfier.positive.W3C_19980720',
 'yalm.resources.tests.classfier.positive.W3C_20150513',
 'yalm.resources.tests.classfier.positive.WTFPL',
 'yalm.resources.tests.classfier.positive.Watcom_1_0',
 'yalm.resources.tests.classfier.positive.Wsuipa',
 'yalm.resources.tests.classfier.positive.X11',
 'yalm.resources.tests.classfier.positive.XFree86_1_1',
 'yalm.resources.tests.classfier.positive.XSkat',
 'yalm.resources.tests.classfier.positive.Xerox',
 'yalm.resources.tests.classfier.positive.Xnet',
 'yalm.resources.tests.classfier.positive.YPL_1_0',
 'yalm.resources.tests.classfier.positive.YPL_1_1',
 'yalm.resources.tests.classfier.positive.ZPL_1_1',
 'yalm.resources.tests.classfier.positive.ZPL_2_0',
 'yalm.resources.tests.classfier.positive.ZPL_2_1',
 'yalm.resources.tests.classfier.positive.Zed',
 'yalm.resources.tests.classfier.positive.Zend_2_0',
 'yalm.resources.tests.classfier.positive.Zimbra_1_3',
 'yalm.resources.tests.classfier.positive.Zimbra_1_4',
 'yalm.resources.tests.classfier.positive.Zlib',
 'yalm.resources.tests.classfier.positive.blessing',
 'yalm.resources.tests.classfier.positive.bzip2_1_0_5',
 'yalm.resources.tests.classfier.positive.bzip2_1_0_6',
 'yalm.resources.tests.classfier.positive.copyleft_next_0_3_0',
 'yalm.resources.tests.classfier.positive.copyleft_next_0_3_1',
 'yalm.resources.tests.classfier.positive.curl',
 'yalm.resources.tests.classfier.positive.diffmark',
 'yalm.resources.tests.classfier.positive.dvipdfm',
 'yalm.resources.tests.classfier.positive.eCos_2_0',
 'yalm.resources.tests.classfier.positive.eGenix',
 'yalm.resources.tests.classfier.positive.etalab_2_0',
 'yalm.resources.tests.classfier.positive.gSOAP_1_3b',
 'yalm.resources.tests.classfier.positive.gnuplot',
 'yalm.resources.tests.classfier.positive.iMatix',
 'yalm.resources.tests.classfier.positive.libpng_2_0',
 'yalm.resources.tests.classfier.positive.libselinux_1_0',
 'yalm.resources.tests.classfier.positive.libtiff',
 'yalm.resources.tests.classfier.positive.mpich2',
 'yalm.resources.tests.classfier.positive.psfrag',
 'yalm.resources.tests.classfier.positive.psutils',
 'yalm.resources.tests.classfier.positive.wxWindows',
 'yalm.resources.tests.classfier.positive.xinetd',
 'yalm.resources.tests.classfier.positive.xpp',
 'yalm.resources.tests.classfier.positive.zlib_acknowledgement',
 'yalm.resources.words',
 'yalm.template']

package_data = \
{'': ['*']}

install_requires = \
['terregex>=0.0.5,<0.0.6']

setup_kwargs = {
    'name': 'yalm',
    'version': '0.0.1a4',
    'description': 'SPDX YALM is a license matching library based on the SPDX License Matching Guideline.',
    'long_description': "# SPDX YALM: Yet Another License Matcher\nSPDX YALM is a license matching library based on [the SPDX License Matching Guideline](https://spdx.dev/license-list/matching-guidelines/).\n\nSPDX is an open standard for communicating software bill of material information. SPDX reduces redundant work by providing common formats for organizations and communities to share important data, thereby streamlining and improving compliance, security, and dependability.\n\nProject YALM is implemented as the matching guideline compliant library - this library provides a way to compare license documents and templates in a standardized way.\n\n## Features\n*    An Interface which compares text against a license template using the license matching guidelines.\n*    An Interface which returns all matching SPDX listed license ID's for any license text.\n*    An interface which compares 2 license texts and returns a boolean indicating if the 2 licenses match per the license matching guidelines.\n*    When there is no match, a return value is provided to describe where and why the license does not match.\n\n## Installation\nEnsure you have installed Python 3.9 or higher.\n\nYou can install this library via [PyPI](https://pypi.org/project/yalm/).\n```\npip install yalm\n```\n\n## License\nCopyright (c) 2021, SPDX YALM Developers.\nFiles in this repository are licensed under\n[Apache License Version 2.0](https://github.com/spdx/tools-python/blob/master/LICENSE).\n\n## Credits\nThis Project is\n- initially developed by [@anshuldutt21](https://github.com/anshuldutt21/)\nas a part of CommunityBridge Linux Foundation 2020.\n- updated by [@m1kit](https://github.com/m1kit) and released\nas a part of Google Summer of Code 2021.\n- with thanks to mentors [@goneall](https://github.com/goneall)\n",
    'author': 'mikit',
    'author_email': 'me@mikit.dev',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/m1kit/yalm-python',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
